# # # # # # # # # # # # # # #
#      Socket Helpers       #
# # # # # # # # # # # # # # #

from sys import argv
from TCPClient import TCPClient

if len(argv) == 3:
	ip = argv[1]
	port = int(argv[2])
else:
	ip = '127.0.0.1'
	port = 1337

TCP = TCPClient(ip, port)

def readString():
	s = TCP.readline()
	print '<', s
	return s

def readArray():
	return readString().split(' ')

def write(s):
	if isinstance(s, (list, tuple)):
		s = ' '.join(s)
	print '>', s
	TCP.writeline(s)

class Bot:
	
	def __init__(self):
		self.name = "AAD"
	
	def play(self):
		readString() # Welcome

		while 1:
			readString() # Start

			self.score = 0
		
			# Name
			write(self.name)
			self.myself = readString()
		
			self.prisoner()
			
			# Game is over, get the final scores
			scores = dict((x.split('=')[0], int(x.split('=')[1])) for x in readArray())
			# scores = { 'Player-1' : 100, 'Player-2' : 23, 'Player-3' : 0, ... }

	def prisoner(self):
		while readString() == 'Prisoner':
	
			# Receive Players
			players = readArray()
	
			# Send T / C
			msg = []
			for player in players:
				if player != self.myself:
					# Cooperate
					action = 'C'
					msg.append('%s=%s' % (player, action))
			write(msg)
	
			# Receive what the others said about me
			actions = dict(x.split('=') for x in readArray())
			# actions = { 'Player-1' : 'C', 'Player-2' : 'T', ... }
			self.pirate()

	def pirate(self):
		while readString() == 'Pirate':
	
			# Receive players and bounty
			data = readArray()
			bounty = int(data[0]) # bounty = 42
			players = data[1:] # players = [ 'Player-1', 'Player-2', ... ]
			# Note: players are sorted by hierarchy, the first is the leader.
	
			nPlayers = len(players)
	
			# We are the leader, let's make a share
			if players[0] == self.myself:
				# How much gold for myself
				forMyself = bounty - int((nPlayers - 1) / 2)

				# Message buffer
				msg = []

				# To which other player should we give gold
				count = 0

				# Players are sorted
				for player in players:
					if player == self.myself:
						share = forMyself
					else:
						if (count == 0):
							share = 1
						else:
							share = 0

						count = (count + 1) % 2

					msg.append('%s=%s' % (player, share))

				# Send proposal to other players
				write(msg)
	
			# We are not the leader, let's see if we accept the share
			else:
				shares = dict((x.split('=')[0], int(x.split('=')[1])) for x in readArray())
				# shares = { 'Player-1' : 50, 'Player-2' : 10, 'Player-3' : 0, ... }
				# If we are given more than 1, we cooperate.
				if shares[self.myself] > 1: 
					action = 'C'
				else:
					action = 'T'
	
				write(action)
	
		# Pirate game is over, let's see how much we got
		self.score += int(readString())

bot = Bot()
bot.play()


